@@ -3,11 +3,9 @@ mod control_test;
 
 use stun::attributes::*;
 use stun::checks::*;
-use stun::errors::ERR_ATTRIBUTE_NOT_FOUND;
 use stun::message::*;
 
-use util::Error;
-
+use anyhow::Result;
 use std::fmt;
 
 /// Common helper for ICE-{CONTROLLED,CONTROLLING} and represents the so-called Tiebreaker number.
@@ -18,7 +16,7 @@ pub(crate) const TIE_BREAKER_SIZE: usize = 8; // 64 bit
 
 impl TieBreaker {
     /// Adds Tiebreaker value to m as t attribute.
-    pub fn add_to_as(self, m: &mut Message, t: AttrType) -> Result<(), Error> {
+    pub fn add_to_as(self, m: &mut Message, t: AttrType) -> Result<()> {
         let mut v = vec![0; TIE_BREAKER_SIZE];
         v.copy_from_slice(&(self.0 as u64).to_be_bytes());
         m.add(t, &v);
@@ -26,7 +24,7 @@ impl TieBreaker {
     }
 
     /// Decodes Tiebreaker value in message getting it as for t type.
-    pub fn get_from_as(&mut self, m: &Message, t: AttrType) -> Result<(), Error> {
+    pub fn get_from_as(&mut self, m: &Message, t: AttrType) -> Result<()> {
         let v = m.get(t)?;
         check_size(t, v.len(), TIE_BREAKER_SIZE)?;
         self.0 = u64::from_be_bytes([v[0], v[1], v[2], v[3], v[4], v[5], v[6], v[7]]);
@@ -39,14 +37,14 @@ pub struct AttrControlled(pub u64);
 
 impl Setter for AttrControlled {
     /// Adds ICE-CONTROLLED to message.
-    fn add_to(&self, m: &mut Message) -> Result<(), Error> {
+    fn add_to(&self, m: &mut Message) -> Result<()> {
         TieBreaker(self.0).add_to_as(m, ATTR_ICE_CONTROLLED)
     }
 }
 
 impl Getter for AttrControlled {
     /// Decodes ICE-CONTROLLED from message.
-    fn get_from(&mut self, m: &Message) -> Result<(), Error> {
+    fn get_from(&mut self, m: &Message) -> Result<()> {
         let mut t = TieBreaker::default();
         t.get_from_as(m, ATTR_ICE_CONTROLLED)?;
         self.0 = t.0;
@@ -60,14 +58,14 @@ pub struct AttrControlling(pub u64);
 
 impl Setter for AttrControlling {
     // add_to adds ICE-CONTROLLING to message.
-    fn add_to(&self, m: &mut Message) -> Result<(), Error> {
+    fn add_to(&self, m: &mut Message) -> Result<()> {
         TieBreaker(self.0).add_to_as(m, ATTR_ICE_CONTROLLING)
     }
 }
 
 impl Getter for AttrControlling {
     // get_from decodes ICE-CONTROLLING from message.
-    fn get_from(&mut self, m: &Message) -> Result<(), Error> {
+    fn get_from(&mut self, m: &Message) -> Result<()> {
         let mut t = TieBreaker::default();
         t.get_from_as(m, ATTR_ICE_CONTROLLING)?;
         self.0 = t.0;
@@ -84,7 +82,7 @@ pub struct AttrControl {
 
 impl Setter for AttrControl {
     // add_to adds ICE-CONTROLLED or ICE-CONTROLLING attribute depending on Role.
-    fn add_to(&self, m: &mut Message) -> Result<(), Error> {
+    fn add_to(&self, m: &mut Message) -> Result<()> {
         if self.role == Role::Controlling {
             self.tie_breaker.add_to_as(m, ATTR_ICE_CONTROLLING)
         } else {
@@ -95,7 +93,7 @@ impl Setter for AttrControl {
 
 impl Getter for AttrControl {
     // get_from decodes Role and Tiebreaker value from message.
-    fn get_from(&mut self, m: &Message) -> Result<(), Error> {
+    fn get_from(&mut self, m: &Message) -> Result<()> {
         if m.contains(ATTR_ICE_CONTROLLING) {
             self.role = Role::Controlling;
             return self.tie_breaker.get_from_as(m, ATTR_ICE_CONTROLLING);
@@ -105,7 +103,7 @@ impl Getter for AttrControl {
             return self.tie_breaker.get_from_as(m, ATTR_ICE_CONTROLLED);
         }
 
-        Err(ERR_ATTRIBUTE_NOT_FOUND.to_owned())
+        Err(stun::error::Error::ErrAttributeNotFound.into())
     }
 }
 
